@@ -18,7 +18,7 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
 
         countneg = sum(map(lambda x: x < 0, ExpClosedf['exp_close']))
         countzero = sum(map(lambda x: x == 0, ExpClosedf['exp_close']))
-        count_perc = round(DirX.DivByZero_int(countneg, (len(ExpCloseDF['exp_close']) - countzero)), 5)
+        count_perc = round(DivByZero_int(countneg, (len(ExpCloseDF['exp_close']) - countzero)), 5)
         # count_perc = "{:.2%}".format(count_perc)
 
         trade_list = s.analyzers.trade_list.get_analysis()
@@ -74,7 +74,7 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
             ##  Won Trades Percentage
             try:
                 won_perc = round(
-                    DirX.DivByZero_int(WonTotal, TotalTrades),
+                    DivByZero_int(WonTotal, TotalTrades),
                     3)
                 # won_perc = "{:.2%}".format(won_perc)
             except:
@@ -161,24 +161,35 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
             ShortPnlWon = np.nan
             ShortPnlLost = np.nan
 
-
         try:
-            if won_perc == 1:
-                ADJ_Wc = ((WonTotal - np.sqrt(WonTotal))/ WonTotal)
-                ADJ_W = ADJ_Wc * WonPnlTotal
-                ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
-                ADJ_L = 0
-            elif won_perc == 0:
-                ADJ_W = 0
-                ADJ_W_BW = 0
-                ADJ_L = ((LostTotal - np.sqrt(LostTotal))/ LostTotal) * LostPnlTotal
-            elif won_perc != 0 and won_perc != 1:
-                ADJ_Wc = ((WonTotal - np.sqrt(WonTotal))/ WonTotal)
+            if TotalTrades > 1:
+                if won_perc == 1:
+                    ADJ_Wc = ((WonTotal - np.sqrt(WonTotal)) / WonTotal)
+                    ADJ_W = ADJ_Wc * WonPnlTotal
+                    ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
+                    ADJ_L = 0
+                elif won_perc == 0:
+                    ADJ_W = 0
+                    ADJ_W_BW = 0
+                    ADJ_L = ((LostTotal - np.sqrt(LostTotal)) / LostTotal) * LostPnlTotal
+                elif won_perc != 0 and won_perc != 1:
+                    ADJ_Wc = ((WonTotal - np.sqrt(WonTotal)) / WonTotal)
 
-                ADJ_W = ADJ_Wc * WonPnlTotal
-                ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
+                    ADJ_W = ADJ_Wc * WonPnlTotal
+                    ADJ_W_BW = ADJ_Wc * (WonPnlTotal - MaxWinning)
+
+                    ADJ_L = ((LostTotal - np.sqrt(LostTotal)) / LostTotal) * LostPnlTotal
+
+            elif TotalTrades == 1:
+                if won_perc == 1:
+                    ADJ_W = WonPnlTotal
+                    ADJ_W_BW = (WonPnlTotal - MaxWinning)
+                    ADJ_L = 0
+                elif won_perc == 0:
+                    ADJ_W = 0
+                    ADJ_W_BW = 0
+                    ADJ_L = LostPnlTotal
 
-                ADJ_L = ((LostTotal - np.sqrt(LostTotal))/ LostTotal) * LostPnlTotal
             elif TotalTrades == np.nan:
                 ADJ_W_BW = np.nan
                 ADJ_W = np.nan
@@ -199,14 +210,14 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
                 profitfactor = np.nan
             else:
                 profitfactor = round(
-                    DirX.DivByZero_int(-WonPnlTotal,LostPnlTotal),3)
+                    DivByZero_int(-WonPnlTotal,LostPnlTotal),3)
         except:
             profitfactor = 0
             print('No Profit')
 
         ##  -----------------      LONG
 
-        won_long_perc = round(DirX.DivByZero_int(LongWon, LongTotal),3)
+        won_long_perc = round(DivByZero_int(LongWon, LongTotal),3)
 
         if LongTotal == 0:
             won_long_perc = np.nan
@@ -219,11 +230,11 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
         elif won_long_perc == np.nan:
             profitfactorlong = np.nan
         else:
-            profitfactorlong = round(DirX.DivByZero_int(-LongPnlWon,LongPnlLost),3)
+            profitfactorlong = round(DivByZero_int(-LongPnlWon,LongPnlLost),3)
 
         ##  -----------------      SHORT
 
-        won_short_perc = round(DirX.DivByZero_int(ShortWon,ShortTotal),3)
+        won_short_perc = round(DivByZero_int(ShortWon,ShortTotal),3)
         if ShortTotal == 0:
             won_short_perc = np.nan
         # won_short_perc = "{:.2%}".format(won_short_perc)
@@ -236,7 +247,7 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
         elif won_short_perc == np.nan:
             profitfactorshort = np.nan
         else:
-            profitfactorshort = round(DirX.DivByZero_int(-ShortPnlWon,ShortPnlLost),
+            profitfactorshort = round(DivByZero_int(-ShortPnlWon,ShortPnlLost),
                 3)
 
         try:
@@ -244,15 +255,15 @@ def Statistics_OPT(opt_runs, margin, Mininbars = 0):
         except:
             avg_bars_trade = np.nan
 
-        avg_pnl = round(DirX.DivByZero_int(totalnet_pnl, TotalTrades), 3)
+        avg_pnl = round(DivByZero_int(totalnet_pnl, TotalTrades), 3)
 
-        PNL_MDWD = round(DirX.DivByZero_int(-totalnet_pnl, MinValue), 3)
+        PNL_MDWD = round(DivByZero_int(-totalnet_pnl, MinValue), 3)
         if totalnet_pnl > 0 and MinValue == 0:
             PNL_MDWD = np.inf
         elif PNL_MDWD == 0:
             PNL_MDWD = np.nan
 
-        EXTFACT = round(DirX.DivByZero_int(-MaxValue, MinValue), 3)
+        EXTFACT = round(DivByZero_int(-MaxValue, MinValue), 3)
         if MaxValue > 0 and MinValue == 0:
             EXTFACT = np.inf
         elif MaxValue == 0 and MinValue < 0:
