@@ -14,4 +14,4 @@ def Terminal2Local():
 Terminal2Local()
 
 # This line of code will allow shorter imports
-from DirectoryFormulas.Directory import DirX
+from DirectoryFormulas.Directories import *
